==> BSgenome.Athaliana.TAIR.04232008_1.3.11.tar.gz: BSgenome.Athaliana.TAIR.04232008/man/package.Rd <==
\name{Athaliana}
\docType{package}

\alias{BSgenome.Athaliana.TAIR.04232008-package}
\alias{BSgenome.Athaliana.TAIR.04232008}
\alias{Athaliana}


\title{Arabidopsis thaliana full genome (TAIR version from April 23, 2008)}

\description{
  Arabidopsis thaliana full genome as provided by TAIR (snapshot from April 23, 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
all the chr*.fas file from ftp://ftp.arabidopsis.org/home/tair/Sequences/whole_chromosomes/
WARNING: This is where things are today (Oct 1st, 2008) but is probably
NOT aimed to be the permanent URL for the 04232008 snapshot of the genome.
TAIR might update the content of this folder in the future with a new
snapshot and move the 04232008 snapshot to the OLD/ subfolder.

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Athaliana
seqlengths(Athaliana)
Athaliana$chr1  # same as Athaliana[["chr1"]]

if ("AGAPS" \%in\% masknames(Athaliana)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    af <- alphabetFrequency(seq)
    found_letters <- names(af)[af != 0]
    if (any(found_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Athaliana)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Athaliana[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Athaliana.TAIR.04232008_1.3.18.tar.gz: BSgenome.Athaliana.TAIR.04232008/man/package.Rd <==
\name{Athaliana}
\docType{package}

\alias{BSgenome.Athaliana.TAIR.04232008-package}
\alias{BSgenome.Athaliana.TAIR.04232008}
\alias{Athaliana}


\title{Arabidopsis thaliana full genome (TAIR version from April 23, 2008)}

\description{
  Arabidopsis thaliana full genome as provided by TAIR (snapshot from April 23, 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
all the chr*.fas file from ftp://ftp.arabidopsis.org/home/tair/Sequences/whole_chromosomes/
WARNING: This is where things are today (Oct 1st, 2008) but is probably
NOT aimed to be the permanent URL for the 04232008 snapshot of the genome.
TAIR might update the content of this folder in the future with a new
snapshot and move the 04232008 snapshot to the OLD/ subfolder.

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Athaliana
seqlengths(Athaliana)
Athaliana$chr1  # same as Athaliana[["chr1"]]

if ("AGAPS" \%in\% masknames(Athaliana)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Athaliana)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Athaliana[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
